A sample project that exists as an aid to the Python Packaging User Guide's Tutorial on Packaging and Distributing Projects.

This project does not aim to cover best practices for Python project development as a whole. For example, it does not provide guidance or tool recommendations for version control, documentation, or testing.

The source for this project is available here.

Most of the configuration for a Python project is done in the setup.py file, an example of which is included in this project. You should edit this file accordingly to adapt this sample project to your needs.

